const { PrismaClient } = require("@prisma/client");
const prisma = new PrismaClient();

// Create a blog
exports.createBlog = async (req, res) => {
  try {
    const { slug, title, body, categoryIDs, tagIDs } = req.body;

    // Create the blog post
    const newBlog = await prisma.blog.create({
      data: {
        slug,
        title,
        body,
        categoryIDs,
        tagIDs,
      },
    });
    res.status(201).json(newBlog);
  } catch (error) {
    console.error("Error creating blog:", error);
    res.status(500).json({ error: "Internal server error" });
  }
};

// Get all blogs
exports.getBlogs = async (req, res) => {
  try {
    const blogs = await prisma.blog.findMany({
      include: { categories: true, tags: true, comments: true },
    });
    res.status(200).json(blogs);
  } catch (error) {
    res.status(500).json({ error: error.message });
  }
};

// Update a blog
exports.updateBlog = async (req, res) => {
  try {
    const { id } = req.params;
    const { slug, title, body, categoryIDs, tagIDs } = req.body;

    // Update the blog
    const updatedBlog = await prisma.blog.update({
      where: { id },
      data: {
        slug,
        title,
        body,
        categoryIDs: categoryIDs.map((id) => new prisma.ObjectId(id)), // Ensure IDs are converted
        tagIDs: tagIDs.map((id) => new prisma.ObjectId(id)), // Ensure IDs are converted
      },
    });

    res.status(200).json(updatedBlog);
  } catch (error) {
    res.status(500).json({ error: error.message });
  }
};

// Delete a blog
exports.deleteBlog = async (req, res) => {
  try {
    const { id } = req.params;
    await prisma.blog.delete({ where: { id } });
    res.status(204).send();
  } catch (error) {
    res.status(500).json({ error: error.message });
  }
};
